@@ -6,7 +6,7 @@ package diff
 import (
 	"encoding/json"
 
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 )
 
 type ChangeSetFilter struct {
