@@ -9,9 +9,9 @@ import (
 	"strings"
 	"testing"
 
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 	uitest "github.com/cppforlife/go-cli-ui/ui/test"
 	"github.com/stretchr/testify/require"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 	"sigs.k8s.io/yaml"
 )
 
